@@ -72,7 +72,7 @@ class GSPeerConnectionWatcherNew:
             await asyncio.sleep(0)
 
     @classmethod
-    async def create(cls, connectionWatcher, gsdbs, target, onframe=None,  on_data_channel=None,
+    async def create(cls, connectionWatcher, gsdbs, target, onframe=None, on_data_channel=None,
                      on_message=None, onmessage=None, ontrack=None, sync=True,
                      framerate=15, ontrackended=None, signalingserver=None):
         self = connectionWatcher
@@ -173,7 +173,6 @@ class GSPeerConnectionWatcherNew:
                 def on_message(message):
                     self.on_message(message)
 
-
             await self.peerConnections.setLocalDescription(await self.peerConnections.createOffer())
             await self.sio.emit("watcher",
                                 {"target": self.target,
@@ -235,7 +234,6 @@ class GSPeerConnectionWatcherNew:
                     def on_message(message):
                         self.on_message(message)
 
-
                 await self.peerConnections.setRemoteDescription(offer)
                 await self.peerConnections.setLocalDescription(await self.peerConnections.createAnswer())
                 await self.sio.emit("answer",
@@ -300,6 +298,7 @@ class FrameBufferThread(Thread):
         self.onframe = onframe
         self.framerate = framerate
         self.nal_queue = Queue(3)
+        self.receivedFrame = False
 
     def write(self, frame):
         if not self.nal_queue.full():
@@ -314,18 +313,20 @@ class FrameBufferThread(Thread):
             elapsed_time = time.time() - start_time
             if elapsed_time > 1 / fps:
 
-                if self.nal_queue.empty():
-                    self.onframe(self.gsdbs, self.target, None)
+                if self.nal_queue.empty() and self.receivedFrame:
+                    self.onframe(self.gsdbs, self.target, None, self.framerate)
                 else:
                     buf = self.nal_queue.get()
+
                 current_fps = frame_count / elapsed_time
                 # print(f'Sync Loop FPS: {elapsed_time:.2f}')
                 if buf is not None or buf:
+                    self.receivedFrame=True
                     start_time = time.time()
                     frame_count = 0
-                    self.onframe(self.gsdbs, self.target, buf,self.framerate)
+                    self.onframe(self.gsdbs, self.target, buf, self.framerate)
                 if elapsed_time > 30:
-                    self.onframe(self.gsdbs, self.target, None,self.framerate)
+                    self.onframe(self.gsdbs, self.target, None, self.framerate)
 
 
 class GSMediaConsumer:
@@ -336,7 +337,7 @@ class GSMediaConsumer:
         self.target = target
         self.onframe = onframe
         self.nal_queue = Queue(3)
-        self.framerate=framerate
+        self.framerate = framerate
         self.broadcastthread = FrameBufferThread(self.gsdbs, self.target, self.onframe, self.framerate)
         self.broadcastthread.start()
 
